Module agent_card

Module agent_card 

Structs

AgentCapabilities
Defines optional capabilities supported by an agent.
AgentCard
The AgentCard is a self-describing manifest for an agent.
AgentCardSignature
Represents a JWS signature of an AgentCard.
AgentExtension
A declaration of a protocol extension supported by an Agent.
AgentInterface
Declares a combination of a target URL and a transport protocol for interacting with the agent.
AgentProvider
Represents the service provider of an agent.
AgentSkill
Represents a distinct capability or function that an agent can perform.

Enums

TransportProtocol
Supported A2A transport protocols.