pub struct AgentCapabilities {
pub streaming: Option<bool>,
pub push_notifications: Option<bool>,
pub state_transition_history: Option<bool>,
pub extensions: Vec<AgentExtension>,
}Expand description
Defines optional capabilities supported by an agent.
Fields
streaming: Option<bool>Indicates if the agent supports Server-Sent Events (SSE) for streaming responses.
push_notifications: Option<bool>Indicates if the agent supports sending push notifications for asynchronous task updates.
state_transition_history: Option<bool>Indicates if the agent provides a history of state transitions for a task.
extensions: Vec<AgentExtension>A list of protocol extensions supported by the agent.