pub enum Content {
Text(String),
Raw(Vec<u8>),
Url(String),
Data(Value),
}Variants
Text(String)
The string content of the text part.
Raw(Vec<u8>)
The raw byte content of a file. In JSON serialization, this is encoded as a base64 string.
Url(String)
A url pointing to the file’s content.
Data(Value)
Arbitrary structured data as a JSON value (object, array, string, number, boolean, or null).
Implementations
Sourceimpl Content
impl Content
Sourcepub fn merge(
field: &mut Option<Content>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Content>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.