pub enum Scheme {
ApiKeySecurityScheme(ApiKeySecurityScheme),
HttpAuthSecurityScheme(HttpAuthSecurityScheme),
Oauth2SecurityScheme(OAuth2SecurityScheme),
OpenIdConnectSecurityScheme(OpenIdConnectSecurityScheme),
MtlsSecurityScheme(MutualTlsSecurityScheme),
}Variants
ApiKeySecurityScheme(ApiKeySecurityScheme)
API key-based authentication.
HttpAuthSecurityScheme(HttpAuthSecurityScheme)
HTTP authentication (Basic, Bearer, etc.).
Oauth2SecurityScheme(OAuth2SecurityScheme)
OAuth 2.0 authentication.
OpenIdConnectSecurityScheme(OpenIdConnectSecurityScheme)
OpenID Connect authentication.
MtlsSecurityScheme(MutualTlsSecurityScheme)
Mutual TLS authentication.
Implementations
Sourceimpl Scheme
impl Scheme
Sourcepub fn merge(
field: &mut Option<Scheme>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Scheme>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.