pub struct AgentCapabilities {
pub streaming: Option<bool>,
pub push_notifications: Option<bool>,
pub extensions: Vec<AgentExtension>,
pub extended_agent_card: Option<bool>,
}Expand description
Defines optional capabilities supported by an agent.
Fields
streaming: Option<bool>Indicates if the agent supports streaming responses.
push_notifications: Option<bool>Indicates if the agent supports sending push notifications for asynchronous task updates.
extensions: Vec<AgentExtension>A list of protocol extensions supported by the agent.
extended_agent_card: Option<bool>Indicates if the agent supports providing an extended agent card when authenticated.
Implementations
Sourceimpl AgentCapabilities
impl AgentCapabilities
Sourcepub fn streaming(&self) -> bool
pub fn streaming(&self) -> bool
Returns the value of streaming, or the default value if streaming is unset.
Sourcepub fn push_notifications(&self) -> bool
pub fn push_notifications(&self) -> bool
Returns the value of push_notifications, or the default value if push_notifications is unset.
Sourcepub fn extended_agent_card(&self) -> bool
pub fn extended_agent_card(&self) -> bool
Returns the value of extended_agent_card, or the default value if extended_agent_card is unset.