pub struct AgentSkill {
pub id: String,
pub name: String,
pub description: String,
pub tags: Vec<String>,
pub examples: Vec<String>,
pub input_modes: Vec<String>,
pub output_modes: Vec<String>,
pub security_requirements: Vec<SecurityRequirement>,
}Expand description
Represents a distinct capability or function that an agent can perform.
Fields
id: StringA unique identifier for the agent’s skill.
name: StringA human-readable name for the skill.
description: StringA detailed description of the skill.
A set of keywords describing the skill’s capabilities.
examples: Vec<String>Example prompts or scenarios that this skill can handle.
input_modes: Vec<String>The set of supported input media types for this skill, overriding the agent’s defaults.
output_modes: Vec<String>The set of supported output media types for this skill, overriding the agent’s defaults.
security_requirements: Vec<SecurityRequirement>Security schemes necessary for this skill.