pub struct ContentTypeNotSupportedError {
pub code: i32,
pub message: String,
pub data: Option<Value>,
}Expand description
An A2A-specific error indicating an incompatibility between the requested content types and the agent’s capabilities.
Fields
code: i32The error code for an unsupported content type.
message: StringThe error message.
data: Option<Value>A primitive or structured value containing additional information about the error.