HttpAuthSecurityScheme

Struct HttpAuthSecurityScheme 

pub struct HttpAuthSecurityScheme {
    pub description: String,
    pub scheme: String,
    pub bearer_format: String,
}
Defines a security scheme using HTTP authentication.

Fields

description: String

An optional description for the security scheme.

scheme: String

The name of the HTTP Authentication scheme to be used in the Authorization header, as defined in RFC7235 (e.g., “Bearer”). This value should be registered in the IANA Authentication Scheme registry.

bearer_format: String

A hint to the client to identify how the bearer token is formatted (e.g., “JWT”). Primarily for documentation purposes.