pub struct InvalidParamsError {
pub code: i32,
pub message: String,
pub data: Option<Value>,
}Expand description
An error indicating that the method parameters are invalid.
Fields
code: i32The error code for an invalid parameters error.
message: StringThe error message.
data: Option<Value>A primitive or structured value containing additional information about the error.