pub struct ListTaskPushNotificationConfigsResponse {
pub configs: Vec<TaskPushNotificationConfig>,
pub next_page_token: String,
}Expand description
Represents a successful response for the ListTaskPushNotificationConfigs
method.
Fields
configs: Vec<TaskPushNotificationConfig>The list of push notification configurations.
next_page_token: StringA token to retrieve the next page of results, or empty if there are no more results in the list.