pub struct ListTasksResponse {
pub tasks: Vec<Task>,
pub next_page_token: String,
pub page_size: i32,
pub total_size: i32,
}Expand description
Result object for ListTasks method containing an array of tasks and pagination information.
Fields
tasks: Vec<Task>Array of tasks matching the specified criteria.
next_page_token: StringA token to retrieve the next page of results, or empty if there are no more results in the list.
page_size: i32The page size used for this response.
total_size: i32Total number of tasks available (before pagination).