pub struct MessageSendConfiguration {
pub blocking: Option<bool>,
pub history_length: Option<i32>,
pub accepted_output_modes: Vec<String>,
pub push_notification_config: Option<PushNotificationConfig>,
}Expand description
Defines configuration options for a message/send or message/stream request.
Fields
blocking: Option<bool>If true, the client will wait for the task to complete. The server may reject this if the task is long-running.
history_length: Option<i32>The number of most recent messages from the task’s history to retrieve in the response.
accepted_output_modes: Vec<String>A list of output MIME types the client is prepared to accept in the response.
push_notification_config: Option<PushNotificationConfig>Configuration for the agent to send push notifications for updates after the initial response.