pub struct TaskPushNotificationConfig {
pub tenant: String,
pub id: String,
pub task_id: String,
pub url: String,
pub token: String,
pub authentication: Option<AuthenticationInfo>,
}Expand description
A container associating a push notification configuration with a specific task.
Fields
tenant: StringOptional. Tenant ID.
id: StringThe push notification configuration details. A unique identifier (e.g. UUID) for this push notification configuration.
task_id: StringThe ID of the task this configuration is associated with.
url: StringThe URL where the notification should be sent.
token: StringA token unique for this task or session.
authentication: Option<AuthenticationInfo>Authentication information required to send the notification.