pub struct TaskStatusUpdateEvent {
pub task_id: String,
pub context_id: String,
pub status: Option<TaskStatus>,
pub metadata: Option<Struct>,
}Expand description
An event sent by the agent to notify the client of a change in a task’s status.
Fields
task_id: StringThe ID of the task that has changed.
context_id: StringThe ID of the context that the task belongs to.
status: Option<TaskStatus>The new status of the task.
metadata: Option<Struct>Optional. Metadata associated with the task update.