pub enum Flow {
AuthorizationCode(AuthorizationCodeOAuthFlow),
ClientCredentials(ClientCredentialsOAuthFlow),
Implicit(ImplicitOAuthFlow),
Password(PasswordOAuthFlow),
DeviceCode(DeviceCodeOAuthFlow),
}Variants
AuthorizationCode(AuthorizationCodeOAuthFlow)
Configuration for the OAuth Authorization Code flow.
ClientCredentials(ClientCredentialsOAuthFlow)
Configuration for the OAuth Client Credentials flow.
Implicit(ImplicitOAuthFlow)
👎Deprecated
Deprecated: Use Authorization Code + PKCE instead.
Password(PasswordOAuthFlow)
👎Deprecated
Deprecated: Use Authorization Code + PKCE or Device Code.
DeviceCode(DeviceCodeOAuthFlow)
Configuration for the OAuth Device Code flow.
Implementations
Sourceimpl Flow
impl Flow
Sourcepub fn merge(
field: &mut Option<Flow>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Flow>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.