pub struct GetTaskRequest {
pub tenant: String,
pub id: String,
pub history_length: Option<i32>,
}Expand description
Represents a request for the GetTask method.
Fields
tenant: StringOptional. Tenant ID, provided as a path parameter.
id: StringThe resource ID of the task to retrieve.
history_length: Option<i32>The maximum number of most recent messages from the task’s history to retrieve. An unset value means the client does not impose any limit. A value of zero is a request to not include any messages. The server MUST NOT return more messages than the provided value, but MAY apply a lower limit.
Implementations
Sourceimpl GetTaskRequest
impl GetTaskRequest
Sourcepub fn history_length(&self) -> i32
pub fn history_length(&self) -> i32
Returns the value of history_length, or the default value if history_length is unset.