pub struct ListTasksRequest {
pub tenant: String,
pub context_id: String,
pub status: i32,
pub page_size: Option<i32>,
pub page_token: String,
pub history_length: Option<i32>,
pub status_timestamp_after: Option<Timestamp>,
pub include_artifacts: Option<bool>,
}Expand description
Parameters for listing tasks with optional filtering criteria.
Fields
tenant: StringTenant ID, provided as a path parameter.
context_id: StringFilter tasks by context ID to get tasks from a specific conversation or session.
status: i32Filter tasks by their current status state.
page_size: Option<i32>The maximum number of tasks to return. The service may return fewer than this value. If unspecified, at most 50 tasks will be returned. The minimum value is 1. The maximum value is 100.
page_token: StringA page token, received from a previous ListTasks call.
ListTasksResponse.next_page_token.
Provide this to retrieve the subsequent page.
history_length: Option<i32>The maximum number of messages to include in each task’s history.
status_timestamp_after: Option<Timestamp>Filter tasks which have a status updated after the provided timestamp in ISO 8601 format (e.g., “2023-10-27T10:00:00Z”). Only tasks with a status timestamp time greater than or equal to this value will be returned.
include_artifacts: Option<bool>Whether to include artifacts in the returned tasks. Defaults to false to reduce payload size.
Implementations
Sourceimpl ListTasksRequest
impl ListTasksRequest
Sourcepub fn status(&self) -> TaskState
pub fn status(&self) -> TaskState
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: TaskState)
pub fn set_status(&mut self, value: TaskState)
Sets status to the provided enum value.
Sourcepub fn page_size(&self) -> i32
pub fn page_size(&self) -> i32
Returns the value of page_size, or the default value if page_size is unset.
Sourcepub fn history_length(&self) -> i32
pub fn history_length(&self) -> i32
Returns the value of history_length, or the default value if history_length is unset.
Sourcepub fn include_artifacts(&self) -> bool
pub fn include_artifacts(&self) -> bool
Returns the value of include_artifacts, or the default value if include_artifacts is unset.