pub struct SendMessageConfiguration {
pub accepted_output_modes: Vec<String>,
pub task_push_notification_config: Option<TaskPushNotificationConfig>,
pub history_length: Option<i32>,
pub return_immediately: bool,
}Expand description
Configuration of a send message request.
Fields
accepted_output_modes: Vec<String>A list of media types the client is prepared to accept for response parts. Agents SHOULD use this to tailor their output.
task_push_notification_config: Option<TaskPushNotificationConfig>Configuration for the agent to send push notifications for task updates.
Task id should be empty when sending this configuration in a SendMessage request.
history_length: Option<i32>The maximum number of most recent messages from the task’s history to retrieve in the response. An unset value means the client does not impose any limit. A value of zero is a request to not include any messages. The server MUST NOT return more messages than the provided value, but MAY apply a lower limit.
return_immediately: boolIf true, the operation returns immediately after creating the task,
even if processing is still in progress.
If false (default), the operation MUST wait until the task reaches a
terminal (COMPLETED, FAILED, CANCELED, REJECTED) or interrupted
(INPUT_REQUIRED, AUTH_REQUIRED) state before returning.
Implementations
Sourceimpl SendMessageConfiguration
impl SendMessageConfiguration
Sourcepub fn history_length(&self) -> i32
pub fn history_length(&self) -> i32
Returns the value of history_length, or the default value if history_length is unset.