pub struct TaskArtifactUpdateEvent {
pub task_id: String,
pub context_id: String,
pub artifact: Option<Artifact>,
pub append: bool,
pub last_chunk: bool,
pub metadata: Option<Struct>,
}Expand description
A task delta where an artifact has been generated.
Fields
task_id: StringThe ID of the task for this artifact.
context_id: StringThe ID of the context that this task belongs to.
artifact: Option<Artifact>The artifact that was generated or updated.
append: boolIf true, the content of this artifact should be appended to a previously sent artifact with the same ID.
last_chunk: boolIf true, this is the final chunk of the artifact.
metadata: Option<Struct>Optional. Metadata associated with the artifact update.