pub struct TaskStatusUpdateEvent {
pub kind: String,
pub task_id: String,
pub context_id: String,
pub status: TaskStatus,
pub is_final: bool,
pub metadata: Option<HashMap<String, Value>>,
}Expand description
An event sent by the agent to notify the client of a change in a task’s status.
Fields
kind: StringThe type of this event. Always “status-update”.
task_id: StringThe ID of the task that was updated.
context_id: StringThe context ID associated with the task.
status: TaskStatusThe new status of the task.
is_final: boolIf true, this is the final event in the stream for this interaction.
metadata: Option<HashMap<String, Value>>Optional metadata for extensions.